/*
 * This file is a part of the CaosDB Project.
 *
 * Copyright (C) 2025 IndiScale GmbH <info@indiscale.com>
 * Copyright (C) 2025 Joscha Schmiedt <joscha@schmiedt.dev>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

package org.caosdb.server.grpc;

import static org.junit.jupiter.api.Assertions.assertEquals;

import java.util.ArrayList;
import org.caosdb.api.scripting.v1alpha1.ExecuteServerSideScriptRequest;
import org.caosdb.api.scripting.v1alpha1.NamedArgument;
import org.caosdb.server.entity.Message;
import org.junit.jupiter.api.Test;

public class ServerSideScriptingGrpcTest {

  @Test
  public void testExecuteServerSideScriptRequestToCommandline() throws Message {
    ExecuteServerSideScriptRequest request =
        ExecuteServerSideScriptRequest.newBuilder()
            .setScriptFilename("my_script.py")
            .addPositionalArguments("pos0")
            .addPositionalArguments("pos1")
            .addNamedArguments(
                NamedArgument.newBuilder().setName("option1").setValue("val1").build())
            .addNamedArguments(
                NamedArgument.newBuilder().setName("option2").setValue("val2").build())
            // .putFiles("-Ofile", "test_file.txt")
            .build();

    ArrayList<String> commandline = ServerSideScriptingServiceImpl.request2CommandLine(request);

    assertEquals(commandline.get(0), "my_script.py");
    assertEquals(commandline.get(1), "--option1=val1");
    assertEquals(commandline.get(2), "--option2=val2");
    assertEquals(commandline.get(3), "pos0");
    assertEquals(commandline.get(4), "pos1");
  }
}
